Struct GasCostSummary
pub struct GasCostSummary {
pub computation_cost: u64,
pub computation_cost_burned: u64,
pub storage_cost: u64,
pub storage_rebate: u64,
pub non_refundable_storage_fee: u64,
}Expand description
Summary of gas charges.
Storage is charged independently of computation. There are 3 parts to the storage charges:
storage_cost: it is the charge of storage at the time the transaction is executed. The cost of storage is the number of bytes of the objects being mutated multiplied by a variable storage cost per bytestorage_rebate: this is the amount a user gets back when manipulating an object. Thestorage_rebateis thestorage_costfor an object minus fees.non_refundable_storage_fee: not all the value of the object storage cost is given back to user and there is a small fraction that is kept by the system. This value tracks that charge.
When looking at a gas cost summary the amount charged to the user is
computation_cost + storage_cost - storage_rebate
and that is the amount that is deducted from the gas coins.
non_refundable_storage_fee is collected from the objects being
mutated/deleted and it is tracked by the system in storage funds.
Objects deleted, including the older versions of objects mutated, have the
storage field on the objects added up to a pool of “potential rebate”. This
rebate then is reduced by the “nonrefundable rate” such that:
potential_rebate(storage cost of deleted/mutated objects) = storage_rebate + non_refundable_storage_fee
BCS
The BCS serialized form for this type is defined by the following ABNF:
gas-cost-summary = u64 ; computation-cost
u64 ; computation-cost-burned
u64 ; storage-cost
u64 ; storage-rebate
u64 ; non-refundable-storage-feeFields
computation_cost: u64Cost of computation/execution
computation_cost_burned: u64The burned component of the computation/execution costs
storage_cost: u64Storage cost, it’s the sum of all storage cost for all objects created or mutated.
storage_rebate: u64The amount of storage cost refunded to the user for all objects deleted or mutated in the transaction.
non_refundable_storage_fee: u64The fee for the rebate. The portion of the storage rebate kept by the system.
Implementations
impl GasCostSummary
impl GasCostSummary
pub fn new(
computation_cost: u64,
computation_cost_burned: u64,
storage_cost: u64,
storage_rebate: u64,
non_refundable_storage_fee: u64,
) -> GasCostSummary
pub fn new( computation_cost: u64, computation_cost_burned: u64, storage_cost: u64, storage_rebate: u64, non_refundable_storage_fee: u64, ) -> GasCostSummary
Create a new gas cost summary.
Arguments
computation_cost- Cost of computation cost/execution.storage_cost- Storage cost, it’s the sum of all storage cost for all objects created or mutated.storage_rebate- The amount of storage cost refunded to the user for all objects deleted or mutated in the transaction.non_refundable_storage_fee- The fee for the rebate. The portion of the storage rebate kept by the system.
pub fn net_gas_usage(&self) -> i64
pub fn net_gas_usage(&self) -> i64
The net gas usage, which is the total gas used minus the storage rebate. A positive number means used gas; negative number means refund.